@@ -1,4 +1,9 @@
 package Log::Contextual::Easy::Package;
+$Log::Contextual::Easy::Package::VERSION = '0.006004';
+# ABSTRACT: Import all logging methods with WarnLogger as default package logger
+
+use strict;
+use warnings;
 
 use base 'Log::Contextual';
 
@@ -19,10 +24,18 @@ sub default_import { qw(:dlog :log ) }
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Log::Contextual::Easy::Package - Import all logging methods with WarnLogger as default package logger
 
+=head1 VERSION
+
+version 0.006004
+
 =head1 SYNOPSIS
 
 In your module:
@@ -59,8 +72,19 @@ For what C<::Package> implies, see L<Log::Contextual/-package_logger>.
 
 =over 4
 
-=item L<Log::Contextual>
-
 =item L<Log::Contextual::Easy::Default>
 
 =back
+
+=head1 AUTHOR
+
+Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
