@@ -1,4 +1,6 @@
 package Log::Contextual::WarnLogger;
+$Log::Contextual::WarnLogger::VERSION = '0.006004';
+# ABSTRACT: logger for libraries using Log::Contextual
 
 use strict;
 use warnings;
@@ -117,9 +119,17 @@ sub _log {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Log::Contextual::WarnLogger - Simple logger for libraries using Log::Contextual
+Log::Contextual::WarnLogger - logger for libraries using Log::Contextual
+
+=head1 VERSION
+
+version 0.006004
 
 =head1 SYNOPSIS
 
@@ -139,8 +149,6 @@ Log::Contextual::WarnLogger - Simple logger for libraries using Log::Contextual
    ...
  }
 
-
-
 =head1 DESCRIPTION
 
 This module is a simple logger made for libraries using L<Log::Contextual>.  We
@@ -155,16 +163,13 @@ works.
 
 Arguments: C<< Dict[ env_prefix => Str, levels => List ] $conf >>
 
- my $l = Log::Contextual::WarnLogger->new({
-   env_prefix => 'BAR'
- });
+ my $l = Log::Contextual::WarnLogger->new({ env_prefix => 'BAR' });
 
 or:
 
  my $l = Log::Contextual::WarnLogger->new({
    env_prefix => 'BAR',
-   levels => [ 'level1', 'level2' ]
-
+   levels => [ 'level1', 'level2' ],
  });
 
 Creates a new logger object where C<env_prefix> defines what the prefix is for
@@ -204,8 +209,6 @@ Note that C<UPTO> is a convenience variable.  If you set
 C<< FOO_UPTO=TRACE >> it will enable all log levels.  Similarly, if you
 set it to C<FATAL> only fatal will be enabled.
 
-=back
-
 =head2 $level
 
 Arguments: C<@anything>
@@ -280,15 +283,13 @@ would expect.
 
 =head1 AUTHOR
 
-See L<Log::Contextual/"AUTHOR">
+Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-See L<Log::Contextual/"COPYRIGHT">
+This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
 
-=head1 LICENSE
-
-See L<Log::Contextual/"LICENSE">
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
